unit AboutAction;

interface

uses
  System.Classes, Vcl.Forms, Vcl.ActnList;

type
  THelpAbout = class(TAction)
  private
    FAboutClass: TCustomFormClass;
  protected
    procedure SetAboutClass(Value: TCustomFormClass);
  public
    function HandlesTarget(Target: TObject): Boolean; override;
    procedure UpdateTarget(Target: TObject); override;
    procedure ExecuteTarget(Target: TObject); override;
    property AboutClass: TCustomFormClass read FAboutClass write SetAboutClass;
  end;

implementation

uses
  ShellAPI;

{ THelpAbout }

procedure THelpAbout.ExecuteTarget(Target: TObject);
var
  About: String;
begin
  if Assigned(AboutClass) then
    with AboutClass.Create(Application) do
      try
        ShowModal
      finally
        Free
      end
  else
  begin
    About := 'Windows ' + Application.Title;
    ShellAbout(Application.MainForm.Handle,
      PChar(About), nil, Application.Icon.Handle)
  end
end;

function THelpAbout.HandlesTarget(Target: TObject): Boolean;
begin
  //This action does not operate on any target controls,
  //so all proposed targets are acceptable
  Result := True
end;

procedure THelpAbout.SetAboutClass(Value: TCustomFormClass);
begin
  if Value <> FAboutClass then
    FAboutClass := Value;
end;

procedure THelpAbout.UpdateTarget(Target: TObject);
begin
  //Whether a custom about form class has been assigned or not,
  //this action will work (it uses the Windows About dialog if
  //no form class has been assigned)
  Enabled := True
end;

end.
